use std::{fs::File, io::Read, process};

use clap::Parser;

mod cpu;

use cpu::CPU;

#[derive(Parser, Debug)]
#[command(author, version, about, long_about = None)]
struct Args {
    /// Name of the compiled LRIS program to run
    filename: String,

    // Enables showing debug information with $FF
    #[arg(short, long, default_value_t = true)]
    debug: bool,
}

fn main() {
    let cli = Args::parse();

    let filename = &cli.filename;

    let mut file = File::open(filename).unwrap_or_else(|_| {
        eprintln!("err: file `{}` doesn't exist", filename);
        process::exit(1);
    });

    let mut buffer = vec![];
    file.read_to_end(&mut buffer).unwrap_or_else(|_| {
        eprintln!("err: failed to read file `{}`", filename);
        process::exit(1);
    });

    let mut cpu = CPU::from_prg_vec(buffer);

    while cpu.is_on {
        cpu.step();
    }
}
